@@ -1,13 +1,14 @@
 package DateTime::Format::Strptime;
-# git description: v1.54-8-g6aa82d9
-$DateTime::Format::Strptime::VERSION = '1.56';
 
 use strict;
 
+our $VERSION = '1.57';
+
 use DateTime 1.00;
 use DateTime::Locale 0.45;
 use DateTime::TimeZone 0.79;
-use Params::Validate 0.64 qw( validate SCALAR SCALARREF BOOLEAN OBJECT CODEREF );
+use Params::Validate 0.64
+    qw( validate SCALAR SCALARREF BOOLEAN OBJECT CODEREF );
 use Carp;
 
 use Exporter;
@@ -140,8 +141,8 @@ sub new {
         "The value supplied to on_error must be either 'croak', 'undef' or a code reference."
         )
         unless ref( $args{on_error} ) eq 'CODE'
-            or $args{on_error} eq 'croak'
-            or $args{on_error} eq 'undef';
+        or $args{on_error} eq 'croak'
+        or $args{on_error} eq 'undef';
 
     # Deal with locale
     unless ( ref( $args{locale} ) ) {
@@ -189,7 +190,7 @@ sub pattern {
     if ($pattern) {
         my $possible_parser = $self->_build_parser($pattern);
         if ( $possible_parser =~ /(%\{\w+\}|%\w)/ and $pattern !~ /\%$1/ ) {
-            $self->local_carp(
+            $self->_local_carp(
                 "Unidentified token in pattern: $1 in $pattern. Leaving old pattern intact."
             ) and return undef;
         }
@@ -208,7 +209,7 @@ sub locale {
     if ($locale) {
         my $possible_locale = DateTime::Locale->load($locale);
         unless ($possible_locale) {
-            $self->local_carp(
+            $self->_local_carp(
                 "Could not create locale from $locale. Leaving old locale intact."
             ) and return undef;
         }
@@ -231,7 +232,7 @@ sub time_zone {
         my $possible_time_zone
             = DateTime::TimeZone->new( name => $time_zone );
         unless ($possible_time_zone) {
-            $self->local_carp(
+            $self->_local_carp(
                 "Could not create time zone from $time_zone. Leaving old time zone intact."
             ) and return undef;
         }
@@ -250,12 +251,12 @@ sub parse_datetime {
 
     # Variables from the parser
     my (
-        $dow_name,   $month_name,        $century,    $day,
-        $hour_24,    $hour_12,           $doy,        $month,
-        $minute,     $ampm,              $second,     $week_sun_0,
-        $dow_sun_0,  $dow_mon_1,         $week_mon_1, $year_100,
-        $year,       $iso_week_year_100, $iso_week_year,
-        $epoch,      $tz_offset,         $timezone,   $tz_olson,
+        $dow_name,  $month_name,        $century,    $day,
+        $hour_24,   $hour_12,           $doy,        $month,
+        $minute,    $ampm,              $second,     $week_sun_0,
+        $dow_sun_0, $dow_mon_1,         $week_mon_1, $year_100,
+        $year,      $iso_week_year_100, $iso_week_year,
+        $epoch,     $tz_offset,         $timezone,   $tz_olson,
         $nanosecond, $ce_year,
 
         $doy_dt, $epoch_dt, $use_timezone, $set_time_zone,
@@ -274,10 +275,10 @@ sub parse_datetime {
     die $@ if $@;
 
     if ( $self->{diagnostic} ) {
-        print qq|
+        print <<"EOF";
 
 Entered     = $time_string
-Parser		= $parser
+Parser      = $parser
 
 dow_name    = $dow_name
 month_name  = $month_name
@@ -305,35 +306,35 @@ epoch       = $epoch
 iso_week_year     = $iso_week_year
 iso_week_year_100 = $iso_week_year_100
 
-		|;
+EOF
 
     }
 
-    $self->local_croak("Your datetime does not match your pattern.")
+    $self->_local_croak("Your datetime does not match your pattern.")
         and return undef
         if ( ( $self->{parser} =~ /\$dow_name\b/ and $dow_name eq '' )
         or ( $self->{parser} =~ /\$month_name\b/ and $month_name eq '' )
-        or ( $self->{parser} =~ /\$century\b/    and $century    eq '' )
-        or ( $self->{parser} =~ /\$day\b/        and $day        eq '' )
-        or ( $self->{parser} =~ /\$hour_24\b/    and $hour_24    eq '' )
-        or ( $self->{parser} =~ /\$hour_12\b/    and $hour_12    eq '' )
-        or ( $self->{parser} =~ /\$doy\b/        and $doy        eq '' )
-        or ( $self->{parser} =~ /\$month\b/      and $month      eq '' )
-        or ( $self->{parser} =~ /\$minute\b/     and $minute     eq '' )
-        or ( $self->{parser} =~ /\$ampm\b/       and $ampm       eq '' )
-        or ( $self->{parser} =~ /\$second\b/     and $second     eq '' )
+        or ( $self->{parser} =~ /\$century\b/    and $century eq '' )
+        or ( $self->{parser} =~ /\$day\b/        and $day eq '' )
+        or ( $self->{parser} =~ /\$hour_24\b/    and $hour_24 eq '' )
+        or ( $self->{parser} =~ /\$hour_12\b/    and $hour_12 eq '' )
+        or ( $self->{parser} =~ /\$doy\b/        and $doy eq '' )
+        or ( $self->{parser} =~ /\$month\b/      and $month eq '' )
+        or ( $self->{parser} =~ /\$minute\b/     and $minute eq '' )
+        or ( $self->{parser} =~ /\$ampm\b/       and $ampm eq '' )
+        or ( $self->{parser} =~ /\$second\b/     and $second eq '' )
         or ( $self->{parser} =~ /\$nanosecond\b/ and $nanosecond eq '' )
         or ( $self->{parser} =~ /\$week_sun_0\b/ and $week_sun_0 eq '' )
-        or ( $self->{parser} =~ /\$dow_sun_0\b/  and $dow_sun_0  eq '' )
-        or ( $self->{parser} =~ /\$dow_mon_1\b/  and $dow_mon_1  eq '' )
+        or ( $self->{parser} =~ /\$dow_sun_0\b/  and $dow_sun_0 eq '' )
+        or ( $self->{parser} =~ /\$dow_mon_1\b/  and $dow_mon_1 eq '' )
         or ( $self->{parser} =~ /\$week_mon_1\b/ and $week_mon_1 eq '' )
-        or ( $self->{parser} =~ /\$year_100\b/   and $year_100   eq '' )
-        or ( $self->{parser} =~ /\$year\b/       and $year       eq '' )
-        or ( $self->{parser} =~ /\$ce_year\b/    and $ce_year    eq '' )
-        or ( $self->{parser} =~ /\$tz_offset\b/  and $tz_offset  eq '' )
-        or ( $self->{parser} =~ /\$tz_olson\b/   and $tz_olson   eq '' )
-        or ( $self->{parser} =~ /\$timezone\b/   and $timezone   eq '' )
-        or ( $self->{parser} =~ /\$epoch\b/      and $epoch      eq '' ) );
+        or ( $self->{parser} =~ /\$year_100\b/   and $year_100 eq '' )
+        or ( $self->{parser} =~ /\$year\b/       and $year eq '' )
+        or ( $self->{parser} =~ /\$ce_year\b/    and $ce_year eq '' )
+        or ( $self->{parser} =~ /\$tz_offset\b/  and $tz_offset eq '' )
+        or ( $self->{parser} =~ /\$tz_olson\b/   and $tz_olson eq '' )
+        or ( $self->{parser} =~ /\$timezone\b/   and $timezone eq '' )
+        or ( $self->{parser} =~ /\$epoch\b/      and $epoch eq '' ) );
 
     # Create a timezone to work with
     if ($tz_offset) {
@@ -341,19 +342,19 @@ iso_week_year_100 = $iso_week_year_100
     }
 
     if ($timezone) {
-        $self->local_croak("I don't recognise the timezone $timezone.")
+        $self->_local_croak("I don't recognise the timezone $timezone.")
             and return undef
             unless $ZONEMAP{$timezone};
-        $self->local_croak("The timezone '$timezone' is ambiguous.")
+        $self->_local_croak("The timezone '$timezone' is ambiguous.")
             and return undef
             if $ZONEMAP{$timezone} eq 'Ambiguous'
-                and not( $tz_offset or $tz_olson );
-        $self->local_croak(
+            and not( $tz_offset or $tz_olson );
+        $self->_local_croak(
             "Your timezones ('$tz_offset' and '$timezone') do not match.")
             and return undef
             if $tz_offset
-                and $ZONEMAP{$timezone} ne 'Ambiguous'
-                and $ZONEMAP{$timezone} != $tz_offset;
+            and $ZONEMAP{$timezone} ne 'Ambiguous'
+            and $ZONEMAP{$timezone} != $tz_offset;
         $use_timezone = $ZONEMAP{$timezone}
             if $ZONEMAP{$timezone} ne 'Ambiguous';
     }
@@ -369,7 +370,7 @@ iso_week_year_100 = $iso_week_year_100
             print "   Trying $tz_olson.\n" if $self->{diagnostic};
             $tz = eval { DateTime::TimeZone->new( name => $tz_olson ) };
         }
-        $self->local_croak("I don't recognise the time zone '$tz_olson'.")
+        $self->_local_croak("I don't recognise the time zone '$tz_olson'.")
             and return undef
             unless $tz;
         $use_timezone = $set_time_zone = $tz;
@@ -417,29 +418,29 @@ iso_week_year_100 = $iso_week_year_100
         }
     }
     if ($year) {
-        $self->local_croak(
+        $self->_local_croak(
             "Your two year values ($year_100 and $year) do not match.")
             and return undef
             if ( $Year && ( $year != $Year ) );
         $Year = $year;
     }
     if ($ce_year) {
-        $self->local_croak(
+        $self->_local_croak(
             "Your two year values ($ce_year and $year) do not match.")
             and return undef
             if ( $Year && ( $ce_year != $Year ) );
         $Year = $ce_year;
     }
-    $self->local_croak("Your year value does not match your epoch.")
+    $self->_local_croak("Your year value does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $Year
-            and $Year != $epoch_dt->year;
+        and $Year
+        and $Year != $epoch_dt->year;
 
     # Work out which month we want
     # Month names
     if ($month_name) {
-        $self->local_croak(
+        $self->_local_croak(
             "There is no use providing a month name ($month_name) without providing a year."
             )
             and return undef
@@ -462,7 +463,7 @@ iso_week_year_100 = $iso_week_year_100
                 $month_count++;
 
                 # When abbreviating, sometimes there's a period, sometimes not.
-                $month      =~ s/\.$//;
+                $month =~ s/\.$//;
                 $month_name =~ s/\.$//;
                 if ( lc $month eq lc $month_name ) {
                     $month_number = $month_count;
@@ -471,34 +472,34 @@ iso_week_year_100 = $iso_week_year_100
             }
         }
         unless ($month_number) {
-            $self->local_croak(
+            $self->_local_croak(
                 "$month_name is not a recognised month in this locale.")
                 and return undef;
         }
         $Month = $month_number;
     }
     if ($month) {
-        $self->local_croak(
+        $self->_local_croak(
             "There is no use providing a month without providing a year.")
             and return undef
             unless $Year;
-        $self->local_croak("$month is too large to be a month of the year.")
+        $self->_local_croak("$month is too large to be a month of the year.")
             and return undef
             unless $month <= 12;
-        $self->local_croak(
+        $self->_local_croak(
             "Your two month values ($month_name and $month) do not match.")
             and return undef
             if $Month
-                and $month != $Month;
+            and $month != $Month;
         $Month = $month;
     }
-    $self->local_croak("Your month value does not match your epoch.")
+    $self->_local_croak("Your month value does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $Month
-            and $Month != $epoch_dt->month;
+        and $Month
+        and $Month != $epoch_dt->month;
     if ($doy) {
-        $self->local_croak(
+        $self->_local_croak(
             "There is no use providing a day of the year without providing a year."
             )
             and return undef
@@ -509,73 +510,73 @@ iso_week_year_100 = $iso_week_year_100
                 time_zone => $use_timezone
             );
         };
-        $self->local_croak("Day of year $Year-$doy is not valid")
+        $self->_local_croak("Day of year $Year-$doy is not valid")
             and return undef
             if $@;
 
         my $month = $doy_dt->month;
-        $self->local_croak( "Your day of the year ($doy - in "
+        $self->_local_croak( "Your day of the year ($doy - in "
                 . $doy_dt->month_name
                 . ") is not in your month ($Month)" )
             and return undef
             if $Month
-                and $month != $Month;
+            and $month != $Month;
         $Month = $month;
     }
-    $self->local_croak("Your day of the year does not match your epoch.")
+    $self->_local_croak("Your day of the year does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $doy_dt
-            and $doy_dt->doy != $epoch_dt->doy;
+        and $doy_dt
+        and $doy_dt->doy != $epoch_dt->doy;
 
     # Day of the month
-    $self->local_croak("$day is too large to be a day of the month.")
+    $self->_local_croak("$day is too large to be a day of the month.")
         and return undef
         unless $day <= 31;
-    $self->local_croak(
+    $self->_local_croak(
         "Your day of the month ($day) does not match your day of the year.")
         and return undef
         if $doy_dt
-            and $day
-            and $day != $doy_dt->day;
+        and $day
+        and $day != $doy_dt->day;
     $Day ||=
           ($day)    ? $day
         : ($doy_dt) ? $doy_dt->day
         :             '';
     if ($Day) {
-        $self->local_croak(
+        $self->_local_croak(
             "There is no use providing a day without providing a month and year."
             )
             and return undef
             unless $Year
-                and $Month;
+            and $Month;
         my $dt = eval {
             DateTime->new(
                 year => $Year + 0, month     => $Month + 0, day => $Day + 0,
                 hour => 12,        time_zone => $use_timezone
             );
         };
-        $self->local_croak("Datetime $Year-$Month-$Day is not a valid date")
+        $self->_local_croak("Datetime $Year-$Month-$Day is not a valid date")
             and return undef
             if $@;
-        $self->local_croak("There is no day $Day in $dt->month_name, $Year")
+        $self->_local_croak("There is no day $Day in $dt->month_name, $Year")
             and return undef
             unless $dt->month == $Month;
     }
-    $self->local_croak("Your day of the month does not match your epoch.")
+    $self->_local_croak("Your day of the month does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $Day
-            and $Day != $epoch_dt->day;
+        and $Day
+        and $Day != $epoch_dt->day;
 
     # Hour of the day
-    $self->local_croak("$hour_24 is too large to be an hour of the day.")
+    $self->_local_croak("$hour_24 is too large to be an hour of the day.")
         and return undef
         unless $hour_24 <= 23;    #OK so leap seconds will break!
-    $self->local_croak("$hour_12 is too large to be an hour of the day.")
+    $self->_local_croak("$hour_12 is too large to be an hour of the day.")
         and return undef
         unless $hour_12 <= 12;
-    $self->local_croak(
+    $self->_local_croak(
         "You must specify am or pm for 12 hour clocks ($hour_12|$ampm).")
         and return undef
         if ( $hour_12 && ( !$ampm ) );
@@ -584,23 +585,23 @@ iso_week_year_100 = $iso_week_year_100
         if ($hour_12) {
             $hour_12 += 12 if $hour_12 and $hour_12 != 12;
         }
-        $self->local_croak(
+        $self->_local_croak(
             "Your am/pm value ($ampm) does not match your hour ($hour_24)")
             and return undef
             if $hour_24
-                and $hour_24 < 12;
+            and $hour_24 < 12;
     }
     elsif ( lc $ampm eq lc $Am ) {
         if ($hour_12) {
             $hour_12 = 0 if $hour_12 == 12;
         }
-        $self->local_croak(
+        $self->_local_croak(
             "Your am/pm value ($ampm) does not match your hour ($hour_24)")
             and return undef
             if $hour_24 >= 12;
     }
     if ( $hour_12 and $hour_24 ) {
-        $self->local_croak(
+        $self->_local_croak(
             "You have specified mis-matching 12 and 24 hour clock information"
             )
             and return undef
@@ -613,46 +614,46 @@ iso_week_year_100 = $iso_week_year_100
     elsif ($hour_24) {
         $Hour = $hour_24;
     }
-    $self->local_croak("Your hour does not match your epoch.")
+    $self->_local_croak("Your hour does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $Hour
-            and $Hour != $epoch_dt->hour;
+        and $Hour
+        and $Hour != $epoch_dt->hour;
     print "Set hour to $Hour.\n" if $self->{diagnostic};
 
     # Minutes
-    $self->local_croak("$minute is too large to be a minute.")
+    $self->_local_croak("$minute is too large to be a minute.")
         and return undef
         unless $minute <= 59;
     $Minute ||= $minute;
-    $self->local_croak("Your minute does not match your epoch.")
+    $self->_local_croak("Your minute does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $Minute
-            and $Minute != $epoch_dt->minute;
+        and $Minute
+        and $Minute != $epoch_dt->minute;
     print "Set minute to $Minute.\n" if $self->{diagnostic};
 
     # Seconds
-    $self->local_croak("$second is too large to be a second.")
+    $self->_local_croak("$second is too large to be a second.")
         and return undef
         unless $second <= 59;    #OK so leap seconds will break!
     $Second ||= $second;
-    $self->local_croak("Your second does not match your epoch.")
+    $self->_local_croak("Your second does not match your epoch.")
         and return undef
         if $epoch_dt
-            and $Second
-            and $Second != $epoch_dt->second;
+        and $Second
+        and $Second != $epoch_dt->second;
     print "Set second to $Second.\n" if $self->{diagnostic};
 
     # Nanoeconds
-    $self->local_croak("$nanosecond is too large to be a nanosecond.")
+    $self->_local_croak("$nanosecond is too large to be a nanosecond.")
         and return undef
         unless length($nanosecond) <= 9;
     $Nanosecond ||= $nanosecond;
     $Nanosecond .= '0' while length($Nanosecond) < 9;
 
-    #	Epoch doesn't return nanoseconds
-    #	croak "Your nanosecond does not match your epoch." if $epoch_dt and $Nanosecond and $Nanosecond != $epoch_dt->nanosecond;
+    #   Epoch doesn't return nanoseconds
+    #   croak "Your nanosecond does not match your epoch." if $epoch_dt and $Nanosecond and $Nanosecond != $epoch_dt->nanosecond;
     print "Set nanosecond to $Nanosecond.\n" if $self->{diagnostic};
 
     my $potential_return = eval {
@@ -670,21 +671,22 @@ iso_week_year_100 = $iso_week_year_100
             time_zone => $use_timezone,
         );
     };
-    $self->local_croak("Datetime is not a valid date") and return undef if $@;
+    $self->_local_croak("Datetime is not a valid date") and return undef
+        if $@;
 
-    $self->local_croak(
+    $self->_local_croak(
         "Your day of the week ($dow_mon_1) does not match the date supplied: "
             . $potential_return->ymd )
         and return undef
         if $dow_mon_1
-            and $potential_return->dow != $dow_mon_1;
+        and $potential_return->dow != $dow_mon_1;
 
-    $self->local_croak(
+    $self->_local_croak(
         "Your day of the week ($dow_sun_0) does not match the date supplied: "
             . $potential_return->ymd )
         and return undef
         if $dow_sun_0
-            and ( $potential_return->dow % 7 ) != $dow_sun_0;
+        and ( $potential_return->dow % 7 ) != $dow_sun_0;
 
     if ($dow_name) {
         my $dow_count  = 0;
@@ -708,42 +710,42 @@ iso_week_year_100 = $iso_week_year_100
             }
         }
         unless ($dow_number) {
-            $self->local_croak(
+            $self->_local_croak(
                 "$dow_name is not a recognised day in this locale.")
                 and return undef;
         }
-        $self->local_croak(
+        $self->_local_croak(
             "Your day of the week ($dow_name) does not match the date supplied: "
                 . $potential_return->ymd )
             and return undef
             if $dow_number
-                and $potential_return->dow != $dow_number;
+            and $potential_return->dow != $dow_number;
     }
 
-    $self->local_croak(
+    $self->_local_croak(
         "Your week number ($week_sun_0) does not match the date supplied: "
             . $potential_return->ymd )
         and return undef
         if $week_sun_0
-            and $potential_return->strftime('%U') != $week_sun_0;
-    $self->local_croak(
+        and $potential_return->strftime('%U') != $week_sun_0;
+    $self->_local_croak(
         "Your week number ($week_mon_1) does not match the date supplied: "
             . $potential_return->ymd )
         and return undef
         if $week_mon_1
-            and $potential_return->strftime('%W') != $week_mon_1;
-    $self->local_croak(
+        and $potential_return->strftime('%W') != $week_mon_1;
+    $self->_local_croak(
         "Your ISO week year ($iso_week_year) does not match the date supplied: "
             . $potential_return->ymd )
         and return undef
         if $iso_week_year
-            and $potential_return->strftime('%G') != $iso_week_year;
-    $self->local_croak(
+        and $potential_return->strftime('%G') != $iso_week_year;
+    $self->_local_croak(
         "Your ISO week year ($iso_week_year_100) does not match the date supplied: "
             . $potential_return->ymd )
         and return undef
         if $iso_week_year_100
-            and $potential_return->strftime('%g') != $iso_week_year_100;
+        and $potential_return->strftime('%g') != $iso_week_year_100;
 
     # Move into the timezone in the object - if there is one
     print "Potential Datetime: "
@@ -793,7 +795,7 @@ sub _build_parser {
     $ampm_list .= '|' . lc $ampm_list;
 
     my $default_date_format = $self->{_locale}->glibc_date_format;
-    my @locale_format = $default_date_format =~ m/(%\{\w+\}|%\d*.)/g;
+    my @locale_format       = $default_date_format =~ m/(%\{\w+\}|%\d*.)/g;
     $default_date_format = join( '', @locale_format );
 
     my $default_time_format = $self->{_locale}->glibc_time_format;
@@ -808,20 +810,20 @@ sub _build_parser {
         "Date format: $default_date_format\nTime format: $default_time_format\nDatetime format: $default_datetime_format\n"
         if $self->{diagnostic};
 
-    $regex      =~ s/%%/__ESCAPED_PERCENT_SIGN_MARKER__/g;
+    $regex =~ s/%%/__ESCAPED_PERCENT_SIGN_MARKER__/g;
     $field_list =~ s/%%/__ESCAPED_PERCENT_SIGN_MARKER__/g;
 
-    $regex      =~ s/%c/$self->{_locale}->glibc_datetime_format/eg;
+    $regex =~ s/%c/$self->{_locale}->glibc_datetime_format/eg;
     $field_list =~ s/%c/$default_datetime_format/eg;
 
     # %c is the locale's default datetime format.
 
-    $regex      =~ s/%x/$self->{_locale}->glibc_date_format/eg;
+    $regex =~ s/%x/$self->{_locale}->glibc_date_format/eg;
     $field_list =~ s/%x/$default_date_format/eg;
 
     # %x is the locale's default date format.
 
-    $regex      =~ s/%X/$self->{_locale}->glibc_time_format/eg;
+    $regex =~ s/%X/$self->{_locale}->glibc_time_format/eg;
     $field_list =~ s/%X/$default_time_format/eg;
 
     # %x is the locale's default time format.
@@ -832,27 +834,27 @@ sub _build_parser {
         $regex =~ s/%\\\{([^\}]+)\\\}/%{$1}/g;
     }
 
-    $regex      =~ s/%T/%H:%M:%S/g;
+    $regex =~ s/%T/%H:%M:%S/g;
     $field_list =~ s/%T/%H%M%S/g;
 
     # %T is the time as %H:%M:%S.
 
-    $regex      =~ s/%r/%I:%M:%S %p/g;
+    $regex =~ s/%r/%I:%M:%S %p/g;
     $field_list =~ s/%r/%I%M%S%p/g;
 
     #is the time as %I:%M:%S %p.
 
-    $regex      =~ s/%R/%H:%M/g;
+    $regex =~ s/%R/%H:%M/g;
     $field_list =~ s/%R/%H%M/g;
 
     #is the time as %H:%M.
 
-    $regex      =~ s|%D|%m\\/%d\\/%y|g;
+    $regex =~ s|%D|%m\\/%d\\/%y|g;
     $field_list =~ s|%D|%m%d%y|g;
 
     #is the same as %m/%d/%y.
 
-    $regex      =~ s|%F|%Y\\-%m\\-%d|g;
+    $regex =~ s|%F|%Y\\-%m\\-%d|g;
     $field_list =~ s|%F|%Y%m%d|g;
 
     #is the same as %Y-%m-%d - the ISO date format.
@@ -865,7 +867,7 @@ sub _build_parser {
             @{ $self->{_locale}->day_format_abbreviated } )
     );
     $day_re .= '|' if $day_re;
-    $regex      =~ s/%a/($day_re\\w+)/gi;
+    $regex =~ s/%a/($day_re\\w+)/gi;
     $field_list =~ s/%a/#dow_name#/gi;
 
     # %a is the day of the week, using the locale's weekday names; either the abbreviated or full name may be specified.
@@ -880,7 +882,7 @@ sub _build_parser {
     );
     $month_re .= '|' if $month_re;
     $month_re .= '[^\\s\\d]+';
-    $regex      =~ s/%[bBh]/($month_re)/g;
+    $regex =~ s/%[bBh]/($month_re)/g;
     $field_list =~ s/%[bBh]/#month_name#/g;
 
     #is the month, using the locale's month names; either the abbreviated or full name may be specified.
@@ -890,131 +892,131 @@ sub _build_parser {
     #s/%c//g;
     #is replaced by the locale's appropriate date and time representation.
 
-    $regex      =~ s/%C/([\\d ]?\\d)/g;
+    $regex =~ s/%C/([\\d ]?\\d)/g;
     $field_list =~ s/%C/#century#/g;
 
     #is the century number [0,99]; leading zeros are permitted by not required.
 
-    $regex      =~ s/%[de]/([\\d ]?\\d)/g;
+    $regex =~ s/%[de]/([\\d ]?\\d)/g;
     $field_list =~ s/%[de]/#day#/g;
 
     #is the day of the month [1,31]; leading zeros are permitted but not required.
     #%e is the same as %d.
 
-    $regex      =~ s/%[Hk]/([\\d ]?\\d)/g;
+    $regex =~ s/%[Hk]/([\\d ]?\\d)/g;
     $field_list =~ s/%[Hk]/#hour_24#/g;
 
     #is the hour (24-hour clock) [0,23]; leading zeros are permitted but not required.
     # %k is the same as %H
 
-    $regex      =~ s/%g/([\\d ]?\\d)/g;
+    $regex =~ s/%g/([\\d ]?\\d)/g;
     $field_list =~ s/%g/#iso_week_year_100#/g;
 
     # The year corresponding to the ISO week number, but without the century (0-99).
 
-    $regex      =~ s/%G/(\\d{4})/g;
+    $regex =~ s/%G/(\\d{4})/g;
     $field_list =~ s/%G/#iso_week_year#/g;
 
     # The year corresponding to the ISO week number.
 
-    $regex      =~ s/%[Il]/([\\d ]?\\d)/g;
+    $regex =~ s/%[Il]/([\\d ]?\\d)/g;
     $field_list =~ s/%[Il]/#hour_12#/g;
 
     #is the hour (12-hour clock) [1-12]; leading zeros are permitted but not required.
     # %l is the same as %I.
 
-    $regex      =~ s/%j/(\\d{1,3})/g;
+    $regex =~ s/%j/(\\d{1,3})/g;
     $field_list =~ s/%j/#doy#/g;
 
     #is the day of the year [1,366]; leading zeros are permitted but not required.
 
-    $regex      =~ s/%m/([\\d ]?\\d)/g;
+    $regex =~ s/%m/([\\d ]?\\d)/g;
     $field_list =~ s/%m/#month#/g;
 
     #is the month number [1-12]; leading zeros are permitted but not required.
 
-    $regex      =~ s/%M/([\\d ]?\\d)/g;
+    $regex =~ s/%M/([\\d ]?\\d)/g;
     $field_list =~ s/%M/#minute#/g;
 
     #is the minute [0-59]; leading zeros are permitted but not required.
 
-    $regex      =~ s/%[nt]/\\s+/g;
+    $regex =~ s/%[nt]/\\s+/g;
     $field_list =~ s/%[nt]//g;
 
     # %n is any white space.
     # %t is any white space.
 
-    $regex      =~ s/%p/($ampm_list)/gi;
+    $regex =~ s/%p/($ampm_list)/gi;
     $field_list =~ s/%p/#ampm#/gi;
 
     # %p is the locale's equivalent of either A.M./P.M. indicator for 12-hour clock.
 
-    $regex      =~ s/%s/(\\d+)/g;
+    $regex =~ s/%s/(\\d+)/g;
     $field_list =~ s/%s/#epoch#/g;
 
     # %s is the seconds since the epoch
 
-    $regex      =~ s/%S/([\\d ]?\\d)/g;
+    $regex =~ s/%S/([\\d ]?\\d)/g;
     $field_list =~ s/%S/#second#/g;
 
     # %S is the seconds [0-61]; leading zeros are permitted but not required.
 
-    $regex      =~ s/%(\d*)N/($1) ? "(\\d{$1})" : "(\\d+)"/eg;
+    $regex =~ s/%(\d*)N/($1) ? "(\\d{$1})" : "(\\d+)"/eg;
     $field_list =~ s/%\d*N/#nanosecond#/g;
 
     # %N is the nanoseconds (or sub seconds really)
 
-    $regex      =~ s/%U/([\\d ]?\\d)/g;
+    $regex =~ s/%U/([\\d ]?\\d)/g;
     $field_list =~ s/%U/#week_sun_0#/g;
 
     # %U is the week number of the year (Sunday as the first day of the week) as a decimal number [0-53]; leading zeros are permitted but not required.
 
-    $regex      =~ s/%w/([0-6])/g;
+    $regex =~ s/%w/([0-6])/g;
     $field_list =~ s/%w/#dow_sun_0#/g;
 
     # is the weekday as a decimal number [0-6], with 0 representing Sunday.
 
-    $regex      =~ s/%u/([1-7])/g;
+    $regex =~ s/%u/([1-7])/g;
     $field_list =~ s/%u/#dow_mon_1#/g;
 
     # is the weekday as a decimal number [1-7], with 1 representing Monday - a la DateTime.
 
-    $regex      =~ s/%W/([\\d ]?\\d)/g;
+    $regex =~ s/%W/([\\d ]?\\d)/g;
     $field_list =~ s/%W/#week_mon_1#/g;
 
     #is the week number of the year (Monday as the first day of the week) as a decimal number [0,53]; leading zeros are permitted but not required.
 
-    $regex      =~ s/%y/([\\d ]?\\d)/g;
+    $regex =~ s/%y/([\\d ]?\\d)/g;
     $field_list =~ s/%y/#year_100#/g;
 
     # is the year within the century. When a century is not otherwise specified, values in the range 69-99 refer to years in the twentieth century (1969 to 1999 inclusive); values in the range 0-68 refer to years in the twenty-first century (2000-2068 inclusive). Leading zeros are permitted but not required.
 
-    $regex      =~ s/%Y/(\\d{4})/g;
+    $regex =~ s/%Y/(\\d{4})/g;
     $field_list =~ s/%Y/#year#/g;
 
     # is the year including the century (for example, 1998).
 
-    $regex      =~ s|%z|([+-]\\d{4})|g;
+    $regex =~ s|%z|([+-]\\d{4})|g;
     $field_list =~ s/%z/#tz_offset#/g;
 
     # Timezone Offset.
 
-    $regex      =~ s|%Z|(\\w+)|g;
+    $regex =~ s|%Z|(\\w+)|g;
     $field_list =~ s/%Z/#timezone#/g;
 
     # The short timezone name.
 
-    $regex      =~ s|%O|(\\w+\\/\\w+)|g;
+    $regex =~ s|%O|(\\w+\\/\\w+)|g;
     $field_list =~ s/%O/#tz_olson#/g;
 
     # The Olson timezone name.
 
-    $regex      =~ s|%\{(\w+)\}|(DateTime->can($1)) ? "(.+)" : ".+"|eg;
+    $regex =~ s|%\{(\w+)\}|(DateTime->can($1)) ? "(.+)" : ".+"|eg;
     $field_list =~ s|(%\{(\w+)\})|(DateTime->can($2)) ? "#$2#" : $1 |eg;
 
     # Any function in DateTime.
 
-    $regex      =~ s/__ESCAPED_PERCENT_SIGN_MARKER__/\\%/g;
+    $regex =~ s/__ESCAPED_PERCENT_SIGN_MARKER__/\\%/g;
     $field_list =~ s/__ESCAPED_PERCENT_SIGN_MARKER__//g;
 
     # is replaced by %.
@@ -1028,7 +1030,7 @@ sub _build_parser {
 
 # Utility functions
 
-sub local_croak {
+sub _local_croak {
     my $self = $_[0];
     return &{ $self->{on_error} }(@_) if ref( $self->{on_error} );
     croak( $_[1] ) if $self->{on_error} eq 'croak';
@@ -1036,7 +1038,7 @@ sub local_croak {
     return ( $self->{on_error} eq 'undef' );
 }
 
-sub local_carp {
+sub _local_carp {
     my $self = $_[0];
     return &{ $self->{on_error} }(@_) if ref( $self->{on_error} );
     carp( $_[1] ) if $self->{on_error} eq 'croak';
@@ -1071,15 +1073,13 @@ __END__
 
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
 DateTime::Format::Strptime - Parse and format strp and strf time patterns
 
 =head1 VERSION
 
-version 1.56
+version 1.57
 
 =head1 SYNOPSIS
 
@@ -1125,6 +1125,8 @@ takes a C<DateTime> and a pattern and returns a string, C<strptime> takes
 a string and a pattern and returns the C<DateTime> object
 associated.
 
+=for Pod::Coverage parse_duration format_duration
+
 =head1 CONSTRUCTOR
 
 =over 4
@@ -1287,7 +1289,7 @@ The day of month (01-31). This will parse single digit numbers as well.
 =item * %D
 
 Equivalent to %m/%d/%y. (This is the American style date, very confusing
-to non-Americans, especially since %d/%m/%y is	widely used in Europe.
+to non-Americans, especially since %d/%m/%y is widely used in Europe.
 The ISO 8601 standard pattern is %F.)
 
 =item * %F
@@ -1443,7 +1445,7 @@ Rick Measham <rickm@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Dave Rolsky.
+This software is Copyright (c) 2015 by Dave Rolsky.
 
 This is free software, licensed under:
 
